pub struct AuthKey { /* private fields */ }Expand description
Telegram’s Authorization Key.
This library does not provide the means to generate a valid key, because doing so relies on (de-)serializing Telegram types.
Implementations