DequeBuffer

Struct DequeBuffer 

pub struct DequeBuffer<T: Copy + Default> { /* private fields */ }
A growable buffer with the properties of a deque.

Unlike the standard VecDeque, this buffer is designed to not need explicit calls to make_contiguous and minimize the amount of memory moves.

Implementations

Source

impl<T: Copy + Default> DequeBuffer<T>

pub fn with_capacity(back_capacity: usize, front_capacity: usize) -> Self

Creates an empty deque buffer with space for at least back_capacity elements in the back, and exactly front_capacity elements in the front.

pub fn clear(&mut self)

Clears the buffer, removing all values.

pub fn extend_front(&mut self, slice: &[T])

Extend the front by copying the elements from slice.

pub fn push(&mut self, value: T)

Appends an element to the back of the buffer.

pub fn is_empty(&self) -> bool

Returns true if the buffer is empty.

pub fn len(&self) -> usize

Returns the number of elements in the buffer.