pub struct DequeBuffer<T: Copy + Default> { /* private fields */ }Expand description
A growable buffer with the properties of a deque.
Unlike the standard VecDeque,
this buffer is designed to not need explicit calls to make_contiguous
and minimize the amount of memory moves.
Implementations
Sourceimpl<T: Copy + Default> DequeBuffer<T>
impl<T: Copy + Default> DequeBuffer<T>
Sourcepub fn with_capacity(back_capacity: usize, front_capacity: usize) -> Self
pub fn with_capacity(back_capacity: usize, front_capacity: usize) -> Self
Creates an empty deque buffer with space for at least back_capacity elements in the back,
and exactly front_capacity elements in the front.
Sourcepub fn extend_front(&mut self, slice: &[T])
pub fn extend_front(&mut self, slice: &[T])
Extend the front by copying the elements from slice.